@@ -10,9 +10,9 @@
 # Copyright © Semantyk 2020. All rights reserved.
 ##################################################
 
-from semantyk.core.resource import Resource
-from semantyk.namespace.namespace import RDFS, SMTK
-from semantyk.uuid_generator import generate_uuid
+from ..core.resource import Resource
+from ..namespace.namespace import RDFS, SMTK
+from ..uuid_generator import generate_uuid
 from rdflib import Literal, URIRef
 
 class Graph(Resource):
