@@ -10,8 +10,8 @@
 # Copyright © Semantyk 2020. All rights reserved. 
 ##################################################
 
-from semantyk.namespace.namespace import RDF, RDFS, SMTK
-from semantyk.uuid_generator import generate_uuid 
+from ..namespace.namespace import RDF, RDFS, SMTK
+from ..uuid_generator import generate_uuid 
 from rdflib import Namespace, URIRef
 
 class Resource(object):
